function bdy_val = bdyfcn(t,x_node,y_node,index_f)

% This is a user-specified function.
%
% Evaluate the Dirichlet boundary data for the exterior region. This also 
% gives the harmonic function u matching that data. This evaluates u at
% points in the exterior region or on its boundary. 
%
% Evaulate u at the points (x_node(i),y_node(i)). When these points are on
% the boundary, the array t contains parameterization points in the given 
% parameterization interval that correspond to (x_node(i),y_node(i)).
%
% This is written in terms of a potential function that is defined on the 
% interior region, but to be evaluated on the exterior region via the 
% Kelvin transform. It is a convenient way to define a harmonic function
% on an external region with a finite limit at infinity (corresponding to 
% (0,0) in the interior region via the Kelvin inversion). 

[x,y] = Kelvin(x_node,y_node);

switch index_f
case 1
    bdy_val = exp(x).*cos(y);
case 2
    bdy_val = x;
case 3
    bdy_val = x.^2 - y.^2;
case 4
    bdy_val = exp(x).*sin(y);
end

end % bdyfcn