function draw_bdy_Kelvin(curve_obj,num_plot_points)

% Draw the Kelvin inversion of the given boundary.
%
% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_plot_points -  The number of subdivisions for the graph of the
%               boundary curve.

% The parameterization interval is [0,L].
curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

h = L/num_plot_points;
plot_points = 0:h:L;
[point_orig,point_kelvin] = generate_curve_Kelvin(plot_points,curve_obj);
xk_plot = point_kelvin.xk; yk_plot = point_kelvin.yk; 
x_plot = point_orig.x; y_plot = point_orig.y; 

figure
hold on
plot(x_plot,y_plot)
plot(xk_plot,yk_plot,'m-.')
plot(xk_plot(1),yk_plot(1),'*')
plot(x_plot(1),y_plot(1),'*')
title('The boundary curve and its inversion')
xlabel('The point corresponding to t=0 is given by *')
legend('Original curve','Transformed curve')
axis equal
hold off

end % draw_bdy_Kelvin