function draw_bdy_with_line(curve_obj,num_plot_points,t)

% This draws the boundary and then draws in a linear line from the given
% interior point. 

% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_plot_points -  The number of subdivisions for the graph of the
%               boundary curve.
% t -           This is the parameterization value to specify the point on
%               the boundary to which the interior point is to be  
%               connected by a straight line.

% The parameterization interval is [0,L].
curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

h = L/num_plot_points;
plot_points = [0:h:L];
[point_orig,point_kelvin] = generate_curve_Kelvin(plot_points,curve_obj);
x_plot = point_kelvin.xk; y_plot = point_kelvin.yk; 
figure
plot(x_plot(1),y_plot(1),'o')
legend('The point corresponding to t=0','Location','Best')
hold on
plot(x_plot,y_plot,'m-')
int_pt = curve_parms.int_pt;
plot(int_pt(1),int_pt(2),'r*')
title('The line segment along which the potential is being evaluated')
xlabel(['t_{bdy} = ',num2str(t)])
axis equal

[point_orig_t,point_kelvin_t] = generate_curve_Kelvin(t,curve_obj);
x_t = point_kelvin_t.xk; y_t = point_kelvin_t.yk; 
q = [0,.95]; 
line_x = (1-q)*int_pt(1) + q*x_t;
line_y = (1-q)*int_pt(2) + q*y_t;
plot(line_x,line_y)
hold off

end % draw_bdy_with_line
