function test_evaluate_potential2_Nystrom_Kelvin(curve_obj,index_bdyf,test)
%
% INPUT:
% curve_obj - This structure contains information on the boundary curve
%             under consideration.
% index_bdyf - The index of the boundary function (Dirichlet data for the
%             determining the potential function.
% test -      This structure contains data obtained earlier when solving
%             the Dirichlet problem using a double layer potential.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;
int_pt = [0 0];
%Initialize based on computations from function Nystrom.
t_nodes = test.t_nodes_Nystrom;
density = test.density_Nystrom;

disp(' ')
disp('CALCULATION OF THE POTENTIAL OVER THE INTERIOR REGION D_i:kelvin')
disp(['Give the number of radial points, extending from the origin',...
                          ' to the boundary?'])
disp(' ')
n_rad = input('n_rad = (We suggest 10) ');
disp(' ')
disp('Give the number of points around the boundary.')
disp(' ')
n_ang = input('n_ang = (We suggest 20) ');
disp(' ')
disp('Numerical integration will be used over the parameterization ')
disp('interval [0,L] for the boundary. The number of nodes is to be an ')
disp('integer multiple of the number of subdivisions used in obtaining ')
disp('the approximating double layer density function. ')
disp(' ')
multiplier = input('multiplier (an integer, 1 or more) = ');

r = 0:1/n_rad:1;
th = 0:L/n_ang:L;

X = zeros(n_ang+1,n_rad+1); Y = zeros(n_ang+1,n_rad+1);
for i=1:n_ang+1
    [~,point_kelvin_tbdy] = generate_curve_Kelvin(th(i),curve_obj);
    xbdy = point_kelvin_tbdy.xk; ybdy = point_kelvin_tbdy.yk; 
    X(i,:) = (1-r)*int_pt(1) + r*xbdy;
    Y(i,:) = (1-r)*int_pt(2) + r*ybdy;
end

potential = zeros(n_ang+1,n_rad+1);
% Calculate potential at points interior to region.
potential(:,1:n_rad) = evaluate_potential_Nystrom_Kelvin(X(:,1:n_rad),...
                     Y(:,1:n_rad),t_nodes,density,index_bdyf,curve_obj,...
                     multiplier);
[XOrig,YOrig] = Kelvin(X,Y);
potential(:,n_rad+1) = bdyfcn([],XOrig(:,n_rad+1),YOrig(:,n_rad+1),...
    index_bdyf);
true_value = bdyfcn([],XOrig,YOrig,index_bdyf);
error = true_value - potential;
disp(' ')
disp(['u(inf) approx = ',num2str(potential(1,1))])
figure
surf(X,Y,potential)
xlabel('\xi')
ylabel('\eta')
zlabel('u')
title('The Nystrom approximate potential U(\xi,\eta)')
pause

max_err = max(max(abs(error)));
disp(['Max error in the Nystrom approximate solution = ',num2str(max_err)])
figure
mesh(X,Y,-log10(abs(error)))
xlabel('\xi')
ylabel('\eta')
zlabel('-log10(error)')
title('The error in the Nystrom approximate potential')

end % test_evaluate_potential2_Nystrom_Kelvin