function test_evaluate_potential_Nystrom_Kelvin(curve_obj,index_bdyf,test)
%
% Test the evaluation of the double layer potential U that is the Kelvin
% transform of the solution u of the exterior Dirichlet problem over the
% exterior region D_e. The potential U is defined on an interior region we 
% call D^_i, obtained by inverting D_e through the unit circle. This
% program approximates U by evaluating along a line from the origin to a 
% point on the boundary of the region D^_i. The user is asked for
% parameters identifying the point on the boundary and the number of
% quadrature nodes to be used.
% 
% INPUT:
% curve_obj - This structure contains information on the boundary curve
%             under consideration.
% index_bdyf - The index of the boundary function (Dirichlet data for the
%             determining the potential function.
% test -      This structure contains data obtained earlier when solving
%             the Dirichlet problem using a double layer potential.

% curve_parms = curve_obj.curve_parms;
% L = curve_parms.length;

%Initialize based on computations from function Nystrom.
t_nodes = test.t_nodes_Nystrom;
num_trap = length(t_nodes);
density = test.density_Nystrom;
int_pt = [0 0];
disp(' ')
disp('CALCULATION OF THE POTENTIAL ALONG A LINE')
disp('Give a point on the boundary by means of its parameterization, say')
disp('t in [0,L]. It is to be joined to the origin, which is assumed to')
disp('be a star-like centerpoint for the interior region obtained by')
disp('inverting the exterior region D_e through the unit circle. The')
disp('solution along it is to be displayed along with its error. The ')
disp('number t is to be chosen in the parameterization interval [0,L].')
disp(' ')
tbdy = input('t = ');
disp(' ')
disp('Numerical integration will be used over the parameterization ')
disp('interval [0,L] for the boundary. The number of nodes is to be an ')
disp('integer multiple of the number of subdivisions used in obtaining ')
disp('the approximating double layer density function. ')
disp(' ')
multiplier = input('multiplier (an integer, 1 or more) = ');

num_plot_points = 200;

draw_bdy_with_line_Kelvin(curve_obj,num_plot_points,tbdy)
pause

[~,point_kelvin_tbdy] = generate_curve_Kelvin(tbdy,curve_obj);
xbdy = point_kelvin_tbdy.xk; ybdy = point_kelvin_tbdy.yk; 
num_pts = 20; h = (0.2/num_pts);
q = (0:h:1-5*h)';
x_eval = (1-q)*int_pt(1) + q*xbdy; y_eval = (1-q)*int_pt(2) + q*ybdy;

potential = evaluate_potential_Nystrom_Kelvin(x_eval,y_eval,t_nodes,...
                        density,index_bdyf,curve_obj,multiplier);
if is_row(potential)
    potential = potential';
end

[xk,yk] = Kelvin(x_eval,y_eval);
true_value = bdyfcn(q,xk,yk,index_bdyf);
error = true_value - potential;

figure
semilogy(q,abs(error))
% min_err = min(abs(error));
title(['Error in potential solution: num:trap = ',num2str(num_trap),...
    ',   multiplier = ',num2str(multiplier)])
xlabel(['q over [0,1):','  parameter t = ',num2str(tbdy),...
    ',   trap nodes over [0,L] = ',num2str(multiplier*num_trap)])
format short

end % test_evaluate_potential_Nystrom