function test_normal_deriv_method_Nystrom_Kelvin(curve_obj,index_bdyf,test)

% For the exterior Dirichlet problem, solved using Nystrom's method for the
% transformed problem (via the Kelvin transform), find the normal 
% derivative. This will be the normal derivative of the solution u to the
% exterior Dirichlet problem.
%
% INPUT:
% curve_obj - This structure contains information on the boundary curve
%             under consideration.
% index_bdyf -  This is the index for the boundary function, given in the
%             external program 'bdyfcn', and its true normal derivative,
%             given in 'normal_deriv_bdyf_Kelvin'.
% test -      This structure contains data obtained earlier when solving
%             the Dirichlet problem using a double layer potential.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

% Recall the dipole density function for the double layer potential
% solving the interior Dirichlet problem for Laplace's equation.
t_nodes = test.t_nodes_Nystrom;
density = test.density_Nystrom;
num_trap = length(t_nodes);

disp(' ')
disp('CALCULATION OF THE NORMAL DERIVATIVE')
disp('Give the integer multiplying factor for the spline interpolant')
disp('nodes of the Nystrom approximation of the double layer density')
disp('function: num_spline = multiplier*num_trap. Experimentally,')
disp('multiplier = 4 or 5 seems a good choice.')
disp(' ')
multiplier_spline = input('multiplier = ');

% Compare our approximate conjugate function and normal derivative to the 
% true values. 
delta = 0;    % Could be changed to an input value > 0, to move away from
              % endpoints and its often greater error.
num_plot = 201; % Number of evaluation and plot points for the 
                % normal derivative.
step_plot = (L-2*delta)/(num_plot-1);
z = step_plot*(0:num_plot-1)' + delta;

% Create the spline interpolant that approximates the conjugate function 
% on the boundary of the curve for the double layer potential.
[~,deriv_cf_values] = eval_spline_conj_fcn_Nystrom_Kelvin(...
    z,curve_obj,t_nodes,density,multiplier_spline,index_bdyf);

[point_orig,~] = generate_curve_Kelvin(z,curve_obj);
true_dv = normal_deriv_bdyf_Kelvin(point_orig,index_bdyf);

figure
plot(z,true_dv,z,deriv_cf_values,'.')
legend('True normal derivative','Approx normal derivative')
title(['Normal derivative approx: Nystroms method',...
    '  num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf)])
pause

error_dv = true_dv - deriv_cf_values;
disp(' '); 
disp(['max error in normal derivative = ',num2str(norm(error_dv,inf))])
figure
plot(z,error_dv,z,error_dv,'.r')
title(['Error in normal derivative: num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf)])

end % test_normal_deriv_method_Nystrom_Kelvin
