function ans_bdyf = bdyfcn(t,x,y,index_f)

% Evaluate the Dirichlet boundary data.  The array t contains
% parameterization points in the given in integration interval.  The points
% (x(i),y(i) correspond to t(i). 
%
% This is written in terms of a potential function that is defined on the 
% interior region D_i, but to be evaluated on the exterior region D_e via 
% inversion through the unit circle. It is a convenient way to define a 
% harmonic function on an external region with a finite limit at infinity 
% (corresponding to (0,0) in the interior region via the Kelvin inversion). 

% Create inversion through unit circle and use Kelvin transform.
rsq = x.^2 + y.^2;
xinv = x./rsq;
yinv = y./rsq;

switch index_f
case 1
%   bdyfcn = exp(xinv)cos(yinv)
    ans_bdyf = exp(xinv).*cos(yinv);
case 2
%   bdyfcn = xinv
    ans_bdyf = xinv;
end

end % bdyfcn