function cans = normal_deriv_bdyf(t,x,y,dx,dy,index_f)

% Evaluate the normal derivative boundary data.  The array t contains
% parameterization points in the given in integration interval.  The 
% points (x(i),y(i) correspond to t(i). This uses the normal that
% points inward from the boundary curve. 

if is_row(x)
    x = x';
    y = y';
end

% Set up inversion through the unit circle and use of Kelvin transform.
rsq = x.^2 + y.^2;
xinv = x./rsq;
yinv = y./rsq;
Dx_xinv = 1./rsq - 2*x.^2 ./rsq.^2;
Dy_xinv = -2*x.*y./rsq.^2;
Dx_yinv = -2*x.*y./rsq.^2;
Dy_yinv = 1./rsq - 2*y.^2 ./rsq.^2;

%%%%%%%%%%%%% USER SPECIFIED MATERIAL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch index_f
case 1
%   bdyfcn = exp(xinv).*cos(yinv);
%   Based on Kelvin transformed function U=exp(x)cos(y)
    dU_dx = exp(xinv).*cos(yinv);
    dU_dy = -exp(xinv).*sin(yinv);   
case 2
%   bdyfcn = xinv/(xinv^2+yinv^2)
%   Based on Kelvin transformed function U=x
    dU_dx = ones(size(x));
    dU_dy = zeros(size(x));
end
%%%%%%%%%%%%% END OF USER SPECIFIED MATERIAL %%%%%%%%%%%%%%%%%%%%%%%%%%%%

dx_bdyf = dU_dx.*Dx_xinv + dU_dy.*Dx_yinv;
dy_bdyf = dU_dx.*Dy_xinv + dU_dy.*Dy_yinv;

% Create inner normal to boundary curve
normal = zeros(length(x),2);
denom = sqrt(dx.^2+dy.^2);
normal(:,1) = -dy./denom; normal(:,2) = dx./denom;
% normal = [-dy,dx]./sqrt(dx.^2+dy.^2);

% Create normal derivative.
cans = dx_bdyf.*normal(:,1)+dy_bdyf.*normal(:,2);

end % normal_deriv_bdyf