function KM = create_coll_matrix(K_matrix,basis_fcns,wq,t_subdiv,...
    num_subdiv,type)

% This generates the collocation matrix, which is composed of integrals
% of K(t_i,s)L_k(s), with t_i a collocation node and L_k(s) a Lagrange
% basis function. These integrals must be evaluated numerically.

num_quad = size(basis_fcns,2);
num_nodes = size(K_matrix,1);
degree = size(basis_fcns,1)-1;
KM = zeros(num_nodes,num_nodes);

for i=1:num_nodes
    for j=1:num_subdiv
        % Do integrals over [t_subdiv(j),t_subdiv(j+1)]. There are
        % degree+1 collocation integrals.
        for k=1:degree+1
            % Do Gaussian quadrature using num_quad nodes
            vec1 = wq.*basis_fcns(k,:)';
            vec2 = K_matrix(i,((j-1)*num_quad+1):j*num_quad);
            sum = dot(vec1,vec2);
            column_index = node_index(j,k,type,degree);
            KM(i,column_index) = KM(i,column_index) + ...
                sum*(t_subdiv(j+1)-t_subdiv(j));
        end
    end
end

end % create_coll_matrix
% --------------------------------------------------------------------

function cans = node_index(j,k,type,degree)

% Determine the index of the node point with local index k in the 
% interval [t_subdiv(j),t_subdiv(j+1)].  It depends on the degree 
% of the piecewise polynomial functions being used, together with
% the value of type describing how the nodes are formed on each 
% subinterval.

switch type
case 'equal'
    cans = (j-1)*degree + k;
case 'gauss'
    cans = (j-1)*(degree+1) + k;
end

end % node_index

            
            