function [vertices,int_pt] = create_polygon(index_bdy)

% This program defines the vertices of the polygonal boundary.  The first 
% and last points in 'vertices' will be joined to complete the curve, taken
% in a counter-clockwise direction. The input parameter 'index_bdy' is used
% to select the particular boundary of interest. The vector vertices(i,:) 
% gives the xy-coordinates of corner #i.
%
% The output point 'int_pt' is a point inside the region with respect to 
% which it is a starlike region. If the region is not starlike, then use
%       int_pt = [NaN,NaN].
% Also in this case, do not use the routines 
% 'test_evaluate_potential_polygon' and 'test_evaluate_potential_polygon2' 
% in the demo program. They assumne the domain is starlike.

switch index_bdy
    case 1  % A square with a triangle-shaped region removed.
        vertices = [-1 -1; 1 -1; 0 0; 1 1; -1 1];
        int_pt = [-.5 0];
    case 2  % An L-shaped domain.
        vertices = [0 0; 2 0; 2 1; 1 1; 1 2; 0 2]; 
        int_pt = [.5 .5];
    case 3  % A square.
        vertices = [-1 -1; 1 -1; 1 1; -1 1];
        int_pt = [0 0];
end

end % create_polygon

