function curve = create_polygon_bdy(vertices,int_pt)

% This creates information needed for a polygonal boundary.  The number of 
% vertices must be greater than 2. The array 'vertices' is to have
% dimension numv x 2, with numv the number of vertices on the boundary. The
% vector vertices(i,:) gives the xy-coordinates of corner #i.

% The two vector int_pt give a point interior to the polgonal region, a
% point with respect to which the region is star-like. If it is not
% starlike, then int_pt = [NaN,NaN].

[nr,nc] = size(vertices);
% Check and if necessary realign the vertices array.
if nr == 2
    vertices = vertices';
end

numv = max(nr,nc);  % Number of vertices

verts = vertices;
verts(numv+1,:) = vertices(1,:);
verts(numv+2,:) = vertices(2,:);

x = verts(:,1); y = verts(:,2);
dx = x(2:numv+2) - x(1:numv+1);
dy = y(2:numv+2) - y(1:numv+1);
Lngth = sqrt(dx.^2 + dy.^2);
Total_length = sum(Lngth(1:numv));

uvx = dx./Lngth; uvy = dy./Lngth;
unit_vec = [uvx uvy ];
dotprd = -uvx(1:numv).*uvx(2:numv+1) - uvy(1:numv).*uvy(2:numv+1);
angle = acos(dotprd);
temp = [angle(numv)
        angle(1:numv-1)];
angle = temp;

midpoints = .5*(verts(1:numv,:)+verts(2:numv+1,:));

breakpoints = zeros(2*numv,1);
for i=1:numv
    breakpoints(2*i-1) = sum(Lngth(1:i-1));
    breakpoints(2*i) = breakpoints(2*i-1) + Lngth(i)/2;
end
breakpoints(2*numv+1) = Total_length;
% Define structure of information for later manipulating the polygon.
poly_curve.name = 'polygon';
poly_curve.Total_length = Total_length;
poly_curve.length = Lngth(1:numv);
poly_curve.vertices = vertices;
poly_curve.dx = dx(1:numv); poly_curve.dy = dy(1:numv);
poly_curve.unit_vec = unit_vec(1:numv,:);
poly_curve.angle = angle;
poly_curve.breakpoints = breakpoints;
poly_curve.midpoints = midpoints;
poly_curve.int_pt = int_pt;

curve.name = 'polygon';
curve.curve_parms = poly_curve;

end % create_polygon_bdy
