function draw_bdy_polygon_with_line(curve_obj,num_plot_points,t)

% Draw the boundary curve and then draw a line segment joining the interior
% starlike point to a point on the boundary. The line segment is not joined
% to the boundary, to show the section along which the double layer
% potential is actually being approximated.
%
% INPUT:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_plot_points -  The number of subdivisions for the graph of the
%               boundary curve.
% t -           This is the parameterization point in [0,L] that is to
%               determine one end of the line segment, the other end being
%               the interior starlike point for the domain.

% The parameterization interval is [0,L].
poly_curve = curve_obj.curve_parms;
L = poly_curve.Total_length;

h = L/num_plot_points;
plot_points = [0:h:L];
[x_plot,~,~,y_plot,~,~] = ...
    generate_curve_polygon(plot_points,curve_obj);

plot(x_plot(1),y_plot(1),'o')
legend('The point corresponding to t=0','Location','Best')
hold on
plot(x_plot,y_plot,'m-')

int_pt = poly_curve.int_pt;
plot(int_pt(1),int_pt(2),'r*')
title('The line segment along which the potential is being evaluated')
xlabel(['t_{bdy} = ',num2str(t)])
axis equal

[x_t,~,~,y_t,~,~] = generate_curve_polygon(t,curve_obj);
q = [0,.95]; 
line_x = (1-q)*int_pt(1) + q*x_t;
line_y = (1-q)*int_pt(2) + q*y_t;
plot(line_x,line_y)
hold off

end % draw_bdy_polygon_with_line