function [x,dx,d2x,y,dy,d2y] = generate_curve_polygon(t,curve_obj)

% Generate the points (x,y) on the boundary curve, corresponding to
% the parameterization variables in t.  We also generate the first 
% and second derivatives of the parameterization function.

% This particular version is for only polygons, and hence the rename from
% the more standard name of 'generate_curve'.

poly_curve = curve_obj.curve_parms;
% This is a polygonal boundary, with the structure poly_curve
% defined in the routine create_polygon_bdy.

% Initialization.
nt = length(t);
nr = size(poly_curve.vertices,1);
vertices = poly_curve.vertices;
breakpoints = poly_curve.breakpoints;
unit_vec = poly_curve.unit_vec;
x = zeros(size(t)); y = zeros(size(t));
dx = zeros(size(t)); dy = zeros(size(t));
d2x = zeros(size(t)); d2y = zeros(size(t));
Lngth = poly_curve.length;

for i=1:nt
    for j=1:nr
        if t(i) >= breakpoints(2*j-1) && t(i) <= breakpoints(2*j+1)
            ji = j;
            s = t(i) - breakpoints(2*ji-1);
            x(i) = vertices(ji,1) + s*unit_vec(ji,1);
            y(i) = vertices(ji,2) + s*unit_vec(ji,2);
            dx(i) = poly_curve.dx(ji)/Lngth(ji); 
            dy(i) = poly_curve.dy(ji)/Lngth(ji);  
            break
        end
    end
end       

end % generate_curve_polygon