function value=interp_density(z,t_subdiv,t_nodes,density,type,degree)

% Interpolate the piecewise polynomial density function, stored in 
% (t_nodes,density), at the scalar z.

% Determine subinterval [t_subdiv(i),t_subdiv(i+1)] containing z.
[lower,upper] = find_interval(z,t_subdiv);
i = lower;

if degree == 0
    value = density(i);
    return
end

% Determine the interpolation nodes and function values.
j_begin = node_index(i,1,type,degree);
j_end = j_begin + degree;
x_nodes = t_nodes(j_begin:j_end);
y_values = density(j_begin:j_end);

% Carry out the interpolation using the divided difference formula.
divdif_y = divdif(x_nodes,y_values);
m = length(x_nodes);
p_eval = divdif_y(m);
for i=m-1:-1:1
    p_eval = divdif_y(i) + (z - x_nodes(i))*p_eval;
end
value = p_eval;

end % interp_density

% --------------------------------------------------------------------

function ans = node_index(j,k,type,degree)

% Determine the index of the node point with local index k in the 
% interval [t_subdiv(j),t_subdiv(j+1)].  It depends on the degree 
% of the piecewise polynomial functions being used, together with
% the value of type describing how the nodes are formed on each 
% subinterval.

switch type
case 'equal'
    ans = (j-1)*degree + k;
case 'gauss'
    ans = (j-1)*(degree+1) + k;
end

end % node_index

% --------------------------------------------------------------------

function divdif_y = divdif(x_nodes,y_values)
%
% This is a function
%         divdif_y = divdif(x_nodes,y_values)
% It calculates the divided differences of the function 
% values given in the vector y_values, which are the values of
% some function f(x) at the nodes given in x_nodes.  On exit, 
%         divdif_y(i) = f[x_1,...,x_i],  i=1,...,m
% with m the length of x_nodes.  The input values x_nodes and
% y_values are not changed by this program.
%
divdif_y = y_values;
m = length(x_nodes);
for i=2:m
    for j=m:-1:i
        divdif_y(j) = (divdif_y(j)-divdif_y(j-1)) ...
                           /(x_nodes(j)-x_nodes(j-i+1));
    end
end

end % divdif_y