function [basis_fcns,zq,wq] = model_quad(degree,type,quad_order)

% This evaluates the Lagrange basis functions relative to the 
% interpolation nodes being used, of which there are degree+1 per
% subdivision of the overall interval of integration.  These are
% evaluated at the Gauss-Legendre points relative to [0,1], of which
% there are quad_order. 

% We require quad_order > 0 and degree >= 0.  If degree=0, then
% use type='gauss'; this is for piecewise constant collocation.

[zq,wq] = gauss_nodes_wts(quad_order,0,1);

switch type
case 'equal'
    t = [0:degree]/degree;
case 'gauss'
    [t,w] = gauss_nodes_wts(degree+1,0,1);
    clear w
end

basis_fcns = zeros(degree+1,quad_order);
for j=1:quad_order
    for i=1:degree+1
        % Evaluate the cardinal basis function corresponding to t(i),
        % doing so at the quadrature point tq(j).
        prod = 1;
        for k=1:degree+1
            if k ~= i
                prod = prod*((zq(j)-t(k))/(t(i)-t(k)));
            end
        end
        basis_fcns(i,j) = prod;
    end
end

end % model_quad