function test_conjugate_function_polygon(curve_obj,degree,...
    cf_quad_order,z,index_bdyf,test)

% Evaluate the conjugate function for the double layer density given in the
% structure 'test'. Evaluate the conjugate function at the parameterization 
% points in z using the formula given in (Miller, page 32).  Use piecewise 
% Gauss-Legendre quadrature, doing so on each subinterval given in 
% t_subdiv, using cf_quad_order points per subinterval.
%
% INPUT
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% degree -      The degree of the piecewise polynomial function.
% cf_quad_order - The number of Gauss-Legendre node points to be used in
%               the numerical integration over each subinterval in the
%               computation of the conjugate function.
% z -           The parameterization points at which the conjugate function
%               is to be evaluated.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.

% Initialization.
% spacing = 'graded';
% type = 'gauss';

% The parameterization interval is [0,L].
% poly_curve = curve_obj.curve_parms;
% L = poly_curve.Total_length;

t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;
num_subdiv = test.num_subdiv;

num_plot = length(z);
conj_fcn_value = zeros(num_plot,1);
true_cf = zeros(length(z),1);
for i=1:num_plot
    [x,~,~,y,~,~] = generate_curve_polygon(z(i),curve_obj);
    conj_fcn_value(i) = conjugate_function_polygon(z(i),x,y,t_nodes,...
               density,curve_obj,t_subdiv,degree,cf_quad_order);
    true_cf(i) = true_conjugate_fcn(x,y,index_bdyf);
end

% Align the true values of the conjugate function with the computed ones.
true_cf = true_cf-true_cf(1)+conj_fcn_value(1);
figure
plot(z,conj_fcn_value,'.',z,true_cf)
legend('Approximation','True')
title(['Conjugate function approx using quadrature: degree = ',...
    num2str(degree),',  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,',   Boundary function ',...
    num2str(index_bdyf),',   quad cf  = ',num2str(cf_quad_order)])
pause

disp(' ')
maxerr = norm(conj_fcn_value-true_cf,inf);
disp(['Max error in the conjugate function using quadrature = ',...
    num2str(maxerr)])
figure
plot(z,conj_fcn_value-true_cf)
title('Error in the quadrature-based conjugate fcn calculation')

end % test_conjugate_function_polygon