function K_matrix = generate_K(num_nodes,num_quad,t_nodes,x_nodes,y_nodes,...
    quad_nodes,x_quad,y_quad,dx_quad,dy_quad,d2x_quad,d2y_quad)

% We evaluate the kernel function K(t,s) with t any collocation node point
% and s any quadrature point.  The quadrature points are used in the 
% Gaussian quadrature of the collocation integrals of K(t_i,s)L_k(s), with 
% t_i a collocation node and L_k(s) a Lagrange basis function.

K_matrix = zeros(num_nodes,num_quad);

for i=1:num_nodes
    point_i = [x_nodes(i),y_nodes(i),t_nodes(i)];
    for j=1:num_quad
        point_j = [x_quad(j),y_quad(j),dx_quad(j),dy_quad(j),...
            d2x_quad(j),d2y_quad(j),quad_nodes(j)];
        K_matrix(i,j) = kernel(point_i,point_j);
    end
end

end % generate_K