function [quad_nodes,quad_weights,num_quad_nodes] = ...
    generate_quad_pts(t_subdiv,quad_order)

% This sets up the nodes and weights for a piecewise Gaussian quadrature
% with quad_order nodes per subdivision, with the subdivision defined 
% in t_subdiv.
%
% INPUT:
% t_subdiv -    The subdivision points for the piecewise polynomial
%               approximation functions.
% quad_order -  The number Gauss-Legendre points to be used in each
%               subinterval when doing numerical integration over [0,L].
%
% OUTPUT:
% quad_nodes -  The quadrature nodes on [0,L].
% quad_weights - The corresponding quadrature weights.
% num_quad_nodes - The length of quad_nodes.

[z,w] = gauss_nodes_wts(quad_order,0,1);
num_subdiv = length(t_subdiv)-1;
nodes = zeros(1,num_subdiv*quad_order);
weights = zeros(1,num_subdiv*quad_order);

for i=1:num_subdiv
    quad_nodes(1+(i-1)*quad_order:i*quad_order) = t_subdiv(i) + ...
        z*(t_subdiv(i+1)-t_subdiv(i));
    quad_weights(1+(i-1)*quad_order:i*quad_order) = ...
        w*(t_subdiv(i+1)-t_subdiv(i));
end    
num_quad_nodes = length(quad_nodes);

end % generate_quad_pts