function value = normal_deriv_bdyf(t,x,y,dx,dy,index_f)

% Evaluate the outer normal derivative of the 'unknown' test function given
% in the program bdyfcn. The points (x_nodes(i),y_nodes(i) correspond 
% to t(i). The parameters x and y should be column vectors.
%
% INPUT:
% t -       The parameter values in [0,L] associated with the boundary 
%           points (x,y).
% x,y -     The coordinates of the boundary points at which the normal
%           derivative is to be evaluated.
% dx,dy -   These are the derivatives at (x,y) of the parameterization 
%           function for the boundary curve.
% index_f - The index for the boundary function, presuming there is more
%           than one to be listed.
%
% OUTPUT:
% value -    The normal derivative at the points (x,y).

if is_row(x)
    x = x';
    y = y';
end

switch index_f
case 1
%   bdyfcn = exp(x).*cos(y);
    dx_bdyf = exp(x).*cos(y);
    dy_bdyf = -exp(x).*sin(y);   
case 2
%   bdyfcn = x;
    dx_bdyf = ones(size(x));
    dy_bdyf = zeros(size(x));
case 3
%   bdyfcn = x.^2 - y.^2;
    dx_bdyf = 2*x;
    dy_bdyf = -2*y;
case 4
%   bdyfcn = 1;
    dx_bdyf = zeros(size(x));
    dy_bdyf = zeros(size(x));
case 5
%   bdyfcn = exp(x).*sin(y);
    dx_bdyf = exp(x).*sin(y);
    dy_bdyf = exp(x).*cos(y);
end

normal = zeros(length(x),2);
denom = sqrt(dx.^2+dy.^2);
normal(:,1) = dy./denom; normal(:,2) = -dx./denom;
% normal = [dy,-dx]./sqrt(dx.^2+dy.^2);

value = dx_bdyf.*normal(:,1)+dy_bdyf.*normal(:,2);

end % normal_deriv_bdyf