function test_evaluate_potential(curve_obj,num_subdiv,degree,type,...
    index_bdyf,int_pt,test)
%
% Test the evaluation of the double layer potential u of the interior 
% Dirichlet problem over the interior region D_i. This program approximates 
% u by evaluating along a line from the starlike interior point int_pt to a 
% point on the boundary, specified by giving the parameterization point t 
% in [0,L]. 
%
% This program should be used only if D_i is starlike with respect to 
% the given internal point 'int_pt'.
% 
% INPUT:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv -  The number of subdivisions for the piecewise polynomial
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% type -        This is either 'equal' or 'gauss', specifying whether the
%               interpolation nodes in each subinterval are to be equally
%               spaced for are to the Gauss-Legendre zeros of the 
%               appropriate order.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% int_pt -      This is a point with respect to which the region D_i is
%               starlike.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.

%curve_parms = curve_obj.curve_parms;
%L = curve_parms.length;

t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;

disp(' ')
disp('Give a point on the boundary by means of its parameterization, say')
disp('t in [0,L]. It is to be joined to the given interior star-like')
disp('centerpoint, and the solution along it is to be displayed along it.')
disp('The number t is to be chosen in the parameterization interval [0,L]')
disp(' ')
tbdy = input('t = ');
disp(' ')
disp('Numerical integration will be used over each subinterval of the ')
disp('boundary curve.  What is the number of quadrature nodes to be ')
disp('used on each subinterval? We suggest 5 or 20, for comparison.')
disp(' ')
pot_quad_order = input('pot_quad_order = ');

num_plot_points = 200;

draw_bdy_with_line(curve_obj,num_plot_points,tbdy)
pause

[xbdy,~,~,ybdy,~,~] = generate_curve(tbdy,curve_obj);
num_pts = 20;
h = (.2/num_pts);
t = 0:h:1-5*h; t = t';
x_eval = (1-t)*int_pt(1) + t*xbdy; y_eval = (1-t)*int_pt(2) + t*ybdy;

potential = evaluate_potential(x_eval,y_eval,t_nodes,density, ...
                        curve_obj,num_subdiv,t_subdiv,degree,...
                        type,pot_quad_order);
if is_row(potential)
    potential = potential';
end
true_value = bdyfcn(t,x_eval,y_eval,index_bdyf);
error = true_value - potential;
%disp('q, x, y, approximate potential, error')
%format short e
%disp([t,x_eval,y_eval,potential,error])
figure
semilogy(t,abs(error))
min_err = min(abs(error));
title(['Error in potential solution: num subdiv = ',num2str(num_subdiv),...
    ',   degree = ',num2str(degree)])
xlabel(['q over [0,1):','  parameter t = ',num2str(tbdy),...
    ',   quad pot = ',num2str(pot_quad_order)])
format short

end % test_evaluate_potential