function rhs = Create_RHS(t,x_t,y_t,index_bdyf,num_quad,curve_obj)

% Create the right hand function g used in (7.1.28) when using a direct
% boundary integral equation for solving the Dirichlet problem. See
% page 315 of my integral equations text.

M = length(t); 
bdyfcn_t = bdyfcn(t,x_t,y_t,index_bdyf);

h = 2*pi/num_quad; s_quad = (h:h:2*pi)';
[x_s,dx_s,d2x_s,y_s,dy_s,d2y_s] = generate_curve(s_quad,curve_obj);
bdyfcn_quad = bdyfcn(s_quad,x_s,y_s,index_bdyf);

rhs = zeros(M,1);
for j=1:M
    point_t = [x_t(j),y_t(j)];
    for k=1:num_quad
        point_s = [x_s(k),y_s(k),dx_s(k),dy_s(k),d2x_s(k),d2y_s(k)];
        rhs(j)= rhs(j) + DoubleLayerKernel(point_t,point_s)*bdyfcn_quad(k);
    end
end

rhs = (h/pi)*rhs + bdyfcn_t;

end % Create_RHS

