function draw_bdy_with_line(curve_obj,num_plot_points,t)

% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_plot_points -  The number of subdivisions for the graph of the
%               boundary curve.

% The parameterization interval is [0,L].
curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

h = L/num_plot_points;
plot_points = [0:h:L];
[x_plot,dx_plot,d2x_plot,y_plot,dy_plot,d2y_plot] = ...
    generate_curve(plot_points,curve_obj);

figure
plot(x_plot(1),y_plot(1),'o')
legend('The point corresponding to t=0','Location','Best')
hold on
plot(x_plot,y_plot,'m-')
int_pt = curve_parms.int_pt;
plot(int_pt(1),int_pt(2),'r*')
title('The line segment along which the potential is being evaluated')
xlabel(['t_{bdy} = ',num2str(t)])
axis equal

[x_t,dx_t,d2x_t,y_t,dy_tt,d2y_t] = generate_curve(t,curve_obj);
q = [0,.95]; 
line_x = (1-q)*int_pt(1) + q*x_t;
line_y = (1-q)*int_pt(2) + q*y_t;
plot(line_x,line_y)
hold off

end % draw_bdy_with_line
