function demo_bie_FirstKind(curve,num_degree,index_bdyf,n_eval)

% Copyright 2013 by Kendall Atkinson
%
% As a demonstration, use one of the following commands and its sample data.
%
%         demo_bie_FirstKind('ellipse',15,1,40)     Use a=2, b=1
%         demo_bie_FirstKind('cardioid',15,1,40)    Use c=0.8, k=1.0, a=b=1
%
% In all cases, we suggest using n_rad=10, n_ang=20 when those are
% requested by the program.

% curve -       This name identifies the boundary.
% num_degree -  The degree of the approximation of the single layer density
%               function. In this program, it is simplified to n.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'bdyfcn'.
% n_eval -      The number of subdivisions to be used in producing a graph
%               of the single layer density rho.

n = num_degree;
disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp(['num_degree = ',num2str(n)])
disp(' ')

[curve_parms, ~, ~] = set_bdy_param(curve);
disp(' ')
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_curve_points = 200;
draw_bdy(curve_obj,num_plot_curve_points)
figure(gcf)
print_curve_data(curve)
pause

[t_at_nodes,rho_at_nodes,cf] = Galerkin_discrete(curve_obj,n,...
    index_bdyf);

h_eval = 2*pi/n_eval; t_eval = h_eval*(0:n_eval)';
[~,dx_nodes,~,~,dy_nodes,~] = ...
                            generate_curve(t_eval,curve_obj);
abs_dr = sqrt(dx_nodes.^2 + dy_nodes.^2);
rho_eval = eval_rho(t_eval,abs_dr,cf);
figure
plot(t_eval,real(rho_eval))
title(['The density \rho_n: n = ',num2str(n)])
xlabel(['n:eval = ',num2str(n_eval)])
pause

test.cf = cf;
test.num_degree = n;
test_evaluate_potential_FirstKind(curve_obj,index_bdyf,test)
test_evaluate_potential2_FirstKind(curve_obj,index_bdyf,test)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;     % Ellipse parameters        
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),...
            '   num:degree = ',num2str(num_degree)])
    case 'cardioid'
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b),...
            '   num:degree = ',num2str(num_degree)])
end
end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % demo_bie_Nystrom

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'cardioid'
        curve_parms.int_pt = [a*c,0];
end

% Allow input of grading parameter for the case of curve='teardrop'.
switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'cardioid'}
        grading_param = 1;
        spacing = 'uniform';
end

end % set_bdy_param
