function potential = evaluate_potential_FirstKind(x_eval,y_eval,cf,...
    num_trap,curve_obj)

% Evaluate the double-layer potential u with the given "density" function
% at the nodes given in (x_eval,y_eval).  x_eval and y_eval can be either
% one or two dimensional arrays. We integrate over each subinterval of the 
% piecewise polynomial function using Gaussian quadrature with "num_pquad" 
% points on that subinterval. As points approach the boundary, a higher
% order numerical integration is needed to preserve the accuracy associated
% with that of the approximating double layer density function.

[nr,nc] = size(x_eval);

% The trapezoidal rule will be used over the boundary when integrating the
% single layer potential integral. The variable num_trap is the number of
% subdivisions to be used in the trapezoidal rule. It should be greater
% than twice the degree of the polynomial approximation rho_n.
h_trap = 2*pi/num_trap; t_trap = h_trap*(1:num_trap)';
[x_nodes,dx_nodes,~,y_nodes,dy_nodes,~] = ...
                            generate_curve(t_trap,curve_obj);
abs_dr = sqrt(dx_nodes.^2 + dy_nodes.^2);
rho_eval = eval_rho(t_trap,abs_dr,cf);

% Evaluate the potential function.
potential = zeros(nr,nc);
for ii=1:nr
    for jj=1:nc
        fk_kernel = log(sqrt((x_eval(ii,jj)-x_nodes).^2 + ...
            (y_eval(ii,jj)-y_nodes).^2));
        potential(ii,jj) = h_trap*sum(fk_kernel.*rho_eval.*abs_dr);
    end
end

end % evaluate_potential

