function test_conjugate_function_Nystrom(curve_obj,index_bdyf,test)

% Find the conjugate function on the boundary for the potential function
% given by dipole density function test.density_Nystrom.
%
% INPUT:
% curve_obj - This structure contains information on the boundary curve
%             under consideration.
% index_bdyf - The index of the boundary function (Dirichlet data for the
%             determining the potential function.
% test -      This structure contains data obtained earlier when solving
%             the Dirichlet problem using a double layer potential.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

% Recall the dipole density function for the double layer potential
% solving the interior Dirichlet problem for Laplace's equation.
t_nodes = test.t_nodes_Nystrom;
density = test.density_Nystrom;
num_trap = length(t_nodes);

disp(' ')
disp('Give the integer multiplying factor for the spline interpolant')
disp('nodes of the Nystrom approximation of the double layer density')
disp('function: num_spline = multiplier*num_trap. Experimentally,')
disp('multiplier = 4 or 5 seems an optimal choice.')
disp(' ')
multiplier_spline = input('multiplier = ');

% Create the spline interpolant that approximates the conjugate function 
% on the boundary of the curve for the double layer potential.
[~,spline_cf] = create_spline_conjugate_fcn_Nystrom(t_nodes,...
   density,curve_obj,multiplier_spline,index_bdyf);

delta = 0;
num_plot = 201;   % Number of points to use in plotting conjugate function.
step_plot = (L-2*delta)/(num_plot-1);
z = step_plot*(0:num_plot-1) + delta;

[x,~,~,y,~,~] = generate_curve(z,curve_obj);
true_cf = true_conjugate_fcn(x,y,index_bdyf);
conj_fcn_value = ppval(spline_cf,z);

midpt = floor((num_plot-1)/2);
figure
true_cf = true_cf - true_cf(midpt) + conj_fcn_value(midpt);
plot(z,conj_fcn_value,z,true_cf,'.')
legend('Approximation','True')
title(['Conjugate fcn approx: Nystroms method',...
    '   num of subdiv = ',num2str(num_trap),...
    '   multiplier = ',num2str(multiplier_spline)])
xlabel(['curve = ',curve_obj.name,...
    '   Boundary function ',num2str(index_bdyf)])
pause

disp(' ')
maxerr = norm(conj_fcn_value-true_cf,inf);
disp(['Max error in the conjugate function = ',...
    num2str(maxerr)])
figure
plot(z,conj_fcn_value-true_cf)
title('Error in the conjugate function using quadrature')
xlabel(['num:trap = ',num2str(num_trap),'   multiplier = ',...
    num2str(multiplier_spline)])

end % test_conjugate_function_Nystrom
