function test_evaluate_potential_Nystrom(curve_obj,index_bdyf,int_pt,test)
%
% Test the evaluation of the double layer potential u of the interior 
% Dirichlet problem over the interior region D_i. This program approximates 
% u by evaluating along a line from the starlike interior point int_pt to a 
% point on the boundary, specified by giving the parameterization point t 
% in [0,L]. 
%
% This program should be used only if D_i is starlike with respect to 
% the given internal point 'int_pt'.
% 
% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% int_pt -      This is a point with respect to which the region D_i is
%               starlike.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the program 'Nystrom'.

% curve_parms = curve_obj.curve_parms;
% L = curve_parms.length;

%Initialize based on computations from function Nystrom.
t_nodes = test.t_nodes_Nystrom;
num_trap = length(t_nodes);
density = test.density_Nystrom;

disp(' ')
disp('Give a point on the boundary by means of its parameterization, say')
disp('t in [0,L]. It is to be joined to the given interior star-like')
disp('centerpoint, and the solution along it is to be displayed along it.')
disp('The number t is to be chosen in the parameterization interval [0,L]')
disp(' ')
tbdy = input('t = ');
disp(' ')
disp('Numerical integration will be used over the parameterization ')
disp('interval [0,L] for the boundary. The number of nodes is to be an ')
disp('integer multiple of the number of subdivisions used in obtaining ')
disp('the approximating double layer density function. ')
disp(' ')
multiplier = input('multiplier (an integer 1 or more) = ');

num_plot_points = 200;

draw_bdy_with_line(curve_obj,num_plot_points,tbdy)
pause

[xbdy,~,~,ybdy,~,~] = generate_curve(tbdy,curve_obj);
num_pts = 20; h = (.2/num_pts);
q = (0:h:1-5*h)';
x_eval = (1-q)*int_pt(1) + q*xbdy; y_eval = (1-q)*int_pt(2) + q*ybdy;

potential = evaluate_potential_Nystrom(x_eval,y_eval,t_nodes,...
                        density,index_bdyf,curve_obj,multiplier);
if is_row(potential)
    potential = potential';
end
true_value = bdyfcn(q,x_eval,y_eval,index_bdyf);
error = true_value - potential;

figure
semilogy(q,abs(error))
% min_err = min(abs(error));
title(['Error in potential solution: num:trap = ',num2str(num_trap),...
    ',   multiplier = ',num2str(multiplier)])
xlabel(['q over [0,1):','  parameter t = ',num2str(tbdy),...
    ',   trap nodes over [0,L] = ',num2str(multiplier*num_trap)])
format short

end % test_evaluate_potential_Nystrom