function [point_orig,point_kelvin] = generate_curve_Kelvin(t,curve_obj)

% Using the program 'generate_curve', apply the Kelvin transform to
% calculate the points (x,y) on the inversion of the given boundary curve, 
% doing so as to correspond to the parameterization variables in t.  We 
% also generate the first and second derivatives of the parameterization 
% function for the inverted % curve.
%
% INPUT;
% t -   The parameterization points at which the curve is to be evaluated.
%       In particular, give the xy-coordinates along with the first and
%       second derivatives of the curve function.
% curve_obj - This structure contains the information about the boundary.
%
% OUTPUT: 
% point_orig - The xy-coordinates along with the first and second 
%       derivatives of the curve function. This is a structure.
% point_kelvin - The xy-coordinates along with the first and second 
%       derivatives of the inversion curve function. This is a structure.

point_orig = generate_curve(t,curve_obj);
x = point_orig.x; y = point_orig.y; 
dx = point_orig.dx; dy = point_orig.dy; 
d2x = point_orig.d2x; d2y = point_orig.d2y; 

rsq = x.^2 + y.^2;
xk = x./rsq; yk = y./rsq;

temp = 2*(x.*dx + y.*dy)./rsq.^2;
dxk = dx./rsq - x.*temp;
dyk = dy./rsq - y.*temp;

drsq = dx.^2 + dy.^2;
temp2 = 8*(x.*dx + y.*dy).^2 ./rsq.^3;
temp3 = 2*(x.*d2x + y.*d2y + drsq)./rsq.^2;
d2xk = d2x./rsq - 2*dx.*temp - x.*temp3 + x.*temp2;
d2yk = d2y./rsq - 2*dy.*temp - y.*temp3 + y.*temp2;

point_kelvin.t = t;
point_kelvin.xk = xk; point_kelvin.yk = yk; 
point_kelvin.dxk = dxk; point_kelvin.dyk = dyk; 
point_kelvin.d2xk = d2xk; point_kelvin.d2yk = d2yk; 

end % generate_curve_Kelvin

